==> cybop-0.18.0.tar.gz: cybop-0.18.0/src/constant/name/cybol/logic/commander/ifconfig_commander_logic_cybol_name.c <==
/*
 * Copyright (C) 1999-2016. Christian Heller.
 *
 * This file is part of the Cybernetics Oriented Interpreter (CYBOI).
 *
 * CYBOI is free software: you can redistribute it and/or modify it
 * under the terms of the GNU General Public License as published
 * by the Free Software Foundation, either version 3 of the License,
 * or (at your option) any later version.
 *
 * CYBOI is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty
 * of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with CYBOI. If not, see <http://www.gnu.org/licenses/>.
 *
 * Cybernetics Oriented Programming (CYBOP) <http://www.cybop.org/>
 * CYBOP Developers <cybop-developers@nongnu.org>
 *
 * @version CYBOP 0.18.0 2016-12-21
 * @author Christian Heller <christian.heller@tuxtax.de>
 */

#ifndef IFCONFIG_COMMANDER_LOGIC_CYBOL_NAME_CONSTANT_SOURCE
#define IFCONFIG_COMMANDER_LOGIC_CYBOL_NAME_CONSTANT_SOURCE

#include <stddef.h>

#include "../../../../../constant/model/cyboi/state/integer_state_cyboi_model.c"

/** The INTERFACE parameter for the IFCONFIG content logic in cybol. */
static wchar_t INTERFACE_IFCONFIG_CONTENT_COMMANDER_LOGIC_CYBOL_NAME_ARRAY[] = {L'i', L'n', L't', L'e', L'r', L'f', L'a', L'c', L'e'};
static wchar_t* INTERFACE_IFCONFIG_CONTENT_COMMANDER_LOGIC_CYBOL_NAME = INTERFACE_IFCONFIG_CONTENT_COMMANDER_LOGIC_CYBOL_NAME_ARRAY;
static int* INTERFACE_IFCONFIG_CONTENT_COMMANDER_LOGIC_CYBOL_NAME_COUNT = NUMBER_9_INTEGER_STATE_CYBOI_MODEL_ARRAY;

/** The UP parameter for the IFCONFIG content logic in cybol. */
static wchar_t UP_IFCONFIG_CONTENT_COMMANDER_LOGIC_CYBOL_NAME_ARRAY[] = {L'u', L'p'};
static wchar_t* UP_IFCONFIG_CONTENT_COMMANDER_LOGIC_CYBOL_NAME = UP_IFCONFIG_CONTENT_COMMANDER_LOGIC_CYBOL_NAME_ARRAY;
static int* UP_IFCONFIG_CONTENT_COMMANDER_LOGIC_CYBOL_NAME_COUNT = NUMBER_2_INTEGER_STATE_CYBOI_MODEL_ARRAY;

/** The DOWN parameter for the IFCONFIG content logic in cybol. */
static wchar_t DOWN_IFCONFIG_CONTENT_COMMANDER_LOGIC_CYBOL_NAME_ARRAY[] = {L'd', L'o', L'w', L'n'};
static wchar_t* DOWN_IFCONFIG_CONTENT_COMMANDER_LOGIC_CYBOL_NAME = DOWN_IFCONFIG_CONTENT_COMMANDER_LOGIC_CYBOL_NAME_ARRAY;
static int* DOWN_IFCONFIG_CONTENT_COMMANDER_LOGIC_CYBOL_NAME_COUNT = NUMBER_4_INTEGER_STATE_CYBOI_MODEL_ARRAY;

/** The SHORT parameter for the IFCONFIG content logic in cybol. */
static wchar_t SHORT_IFCONFIG_CONTENT_COMMANDER_LOGIC_CYBOL_NAME_ARRAY[] = {L's', L'h', L'o', L'r', L't'};
static wchar_t* SHORT_IFCONFIG_CONTENT_COMMANDER_LOGIC_CYBOL_NAME = SHORT_IFCONFIG_CONTENT_COMMANDER_LOGIC_CYBOL_NAME_ARRAY;
static int* SHORT_IFCONFIG_CONTENT_COMMANDER_LOGIC_CYBOL_NAME_COUNT = NUMBER_5_INTEGER_STATE_CYBOI_MODEL_ARRAY;

/** The ALL parameter for the IFCONFIG content logic in cybol. */
static wchar_t ALL_IFCONFIG_CONTENT_COMMANDER_LOGIC_CYBOL_NAME_ARRAY[] = {L'a', L'l', L'l'};
static wchar_t* ALL_IFCONFIG_CONTENT_COMMANDER_LOGIC_CYBOL_NAME = ALL_IFCONFIG_CONTENT_COMMANDER_LOGIC_CYBOL_NAME_ARRAY;
static int* ALL_IFCONFIG_CONTENT_COMMANDER_LOGIC_CYBOL_NAME_COUNT = NUMBER_3_INTEGER_STATE_CYBOI_MODEL_ARRAY;

/* IFCONFIG_COMMANDER_LOGIC_CYBOL_NAME_CONSTANT_SOURCE */
#endif

==> cybop-0.19.0.tar.gz: cybop-0.19.0/src/constant/name/cybol/logic/commander/ifconfig_commander_logic_cybol_name.c <==
/*
 * Copyright (C) 1999-2017. Christian Heller.
 *
 * This file is part of the Cybernetics Oriented Interpreter (CYBOI).
 *
 * CYBOI is free software: you can redistribute it and/or modify it
 * under the terms of the GNU General Public License as published
 * by the Free Software Foundation, either version 3 of the License,
 * or (at your option) any later version.
 *
 * CYBOI is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty
 * of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with CYBOI. If not, see <http://www.gnu.org/licenses/>.
 *
 * Cybernetics Oriented Programming (CYBOP) <http://www.cybop.org/>
 * CYBOP Developers <cybop-developers@nongnu.org>
 *
 * @version CYBOP 0.19.0 2017-04-10
 * @author Christian Heller <christian.heller@tuxtax.de>
 */

#ifndef IFCONFIG_COMMANDER_LOGIC_CYBOL_NAME_CONSTANT_SOURCE
#define IFCONFIG_COMMANDER_LOGIC_CYBOL_NAME_CONSTANT_SOURCE

#include <stddef.h>

#include "../../../../../constant/model/cyboi/state/integer_state_cyboi_model.c"

/** The INTERFACE parameter for the IFCONFIG content logic in cybol. */
static wchar_t* INTERFACE_IFCONFIG_CONTENT_COMMANDER_LOGIC_CYBOL_NAME = L"interface";
static int* INTERFACE_IFCONFIG_CONTENT_COMMANDER_LOGIC_CYBOL_NAME_COUNT = NUMBER_9_INTEGER_STATE_CYBOI_MODEL_ARRAY;

/** The UP parameter for the IFCONFIG content logic in cybol. */
static wchar_t* UP_IFCONFIG_CONTENT_COMMANDER_LOGIC_CYBOL_NAME = L"up";
static int* UP_IFCONFIG_CONTENT_COMMANDER_LOGIC_CYBOL_NAME_COUNT = NUMBER_2_INTEGER_STATE_CYBOI_MODEL_ARRAY;

/** The DOWN parameter for the IFCONFIG content logic in cybol. */
static wchar_t* DOWN_IFCONFIG_CONTENT_COMMANDER_LOGIC_CYBOL_NAME = L"down";
static int* DOWN_IFCONFIG_CONTENT_COMMANDER_LOGIC_CYBOL_NAME_COUNT = NUMBER_4_INTEGER_STATE_CYBOI_MODEL_ARRAY;

/** The SHORT parameter for the IFCONFIG content logic in cybol. */
static wchar_t* SHORT_IFCONFIG_CONTENT_COMMANDER_LOGIC_CYBOL_NAME = L"short";
static int* SHORT_IFCONFIG_CONTENT_COMMANDER_LOGIC_CYBOL_NAME_COUNT = NUMBER_5_INTEGER_STATE_CYBOI_MODEL_ARRAY;

/** The ALL parameter for the IFCONFIG content logic in cybol. */
static wchar_t* ALL_IFCONFIG_CONTENT_COMMANDER_LOGIC_CYBOL_NAME = L"all";
static int* ALL_IFCONFIG_CONTENT_COMMANDER_LOGIC_CYBOL_NAME_COUNT = NUMBER_3_INTEGER_STATE_CYBOI_MODEL_ARRAY;

/* IFCONFIG_COMMANDER_LOGIC_CYBOL_NAME_CONSTANT_SOURCE */
#endif
